@@ -79,6 +79,13 @@ void RRNGMIX(int    *IDum,        /* Random seed. */
 				InpParType.Theta[j][k].Par1 = Par1[i];
 			}
 			else
+			if (!strcmp(ParFamType[i], "GAMMA")) {
+  			    InpParType.Theta[j][k].ParFamType = pfGamma; strcpy(ParFamType[i], "gamma");
+
+				InpParType.Theta[j][k].Par0 = Par0[i];
+				InpParType.Theta[j][k].Par1 = Par1[i];
+			}
+			else
 			if (!strcmp(ParFamType[i], "BINOMIAL")) {
   			    InpParType.Theta[j][k].ParFamType = pfBinomial; strcpy(ParFamType[i], "binomial");
 
@@ -310,6 +317,10 @@ void RREBMIX(char   **PreType,    /* Preprocessing of observations. */
   		    InpParType.IniFamType[i] = pfWeibull; strcpy(IniFamType[i], "Weibull");
 		}
 		else
+		if (!strcmp(IniFamType[i], "GAMMA")) {
+  		    InpParType.IniFamType[i] = pfGamma; strcpy(IniFamType[i], "gamma");
+		}
+		else
 		if (!strcmp(IniFamType[i], "BINOMIAL")) {
   		    InpParType.IniFamType[i] = pfBinomial; strcpy(IniFamType[i], "binomial");
 		}
@@ -472,6 +483,13 @@ void RREBMIX(char   **PreType,    /* Preprocessing of observations. */
 				Par0[i] = OutParType.Theta[j][l].Par0;
 				Par1[i] = OutParType.Theta[j][l].Par1;
 
+				break;
+            case pfGamma:
+				strcpy(ParFamType[i], "gamma");
+
+				Par0[i] = OutParType.Theta[j][l].Par0;
+				Par1[i] = OutParType.Theta[j][l].Par1;
+
 				break;
             case pfBinomial:
 				strcpy(ParFamType[i], "binomial");
@@ -923,6 +941,13 @@ void RCLSMIX(int    *n,           /* Total number of independent observations. *
 						Theta[j][k][l][m].Par1 = Par1[i];
 					}
 					else
+					if (!strcmp(ParFamType[i], "GAMMA")) {
+  						Theta[j][k][l][m].ParFamType = pfGamma; strcpy(ParFamType[i], "gamma");
+
+						Theta[j][k][l][m].Par0 = Par0[i];
+						Theta[j][k][l][m].Par1 = Par1[i];
+					}
+					else
 					if (!strcmp(ParFamType[i], "BINOMIAL")) {
   						Theta[j][k][l][m].ParFamType = pfBinomial; strcpy(ParFamType[i], "binomial");
 
@@ -1081,6 +1106,13 @@ void RCLRMIX(int    *n,           /* Total number of independent observations. *
 				Theta[j][k].Par1 = Par1[i];
 			}
 			else
+			if (!strcmp(ParFamType[i], "GAMMA")) {
+  			    Theta[j][k].ParFamType = pfGamma; strcpy(ParFamType[i], "gamma");
+
+				Theta[j][k].Par0 = Par0[i];
+				Theta[j][k].Par1 = Par1[i];
+			}
+			else
 			if (!strcmp(ParFamType[i], "BINOMIAL")) {
   			    Theta[j][k].ParFamType = pfBinomial; strcpy(ParFamType[i], "binomial");
 
@@ -1511,6 +1543,13 @@ void RInformationCriterionKNN(int    *k,           /* Total number of bins. */
 				OutParType.Theta[j][l].Par1 = Par1[i];
 			}
 			else
+			if (!strcmp(ParFamType[i], "GAMMA")) {
+  				OutParType.Theta[j][l].ParFamType = pfGamma;  strcpy(ParFamType[i], "gamma");
+
+				OutParType.Theta[j][l].Par0 = Par0[i];
+				OutParType.Theta[j][l].Par1 = Par1[i];
+			}
+			else
 			if (!strcmp(ParFamType[i], "BINOMIAL")) {
   				OutParType.Theta[j][l].ParFamType = pfBinomial;  strcpy(ParFamType[i], "binomial");
 
@@ -1717,6 +1756,13 @@ void RInformationCriterionPW(double *h,           /* Sides of the hypersquare. *
 				OutParType.Theta[j][l].Par1 = Par1[i];
 			}
 			else
+			if (!strcmp(ParFamType[i], "GAMMA")) {
+  				OutParType.Theta[j][l].ParFamType = pfGamma;  strcpy(ParFamType[i], "gamma");
+
+				OutParType.Theta[j][l].Par0 = Par0[i];
+				OutParType.Theta[j][l].Par1 = Par1[i];
+			}
+			else
 			if (!strcmp(ParFamType[i], "BINOMIAL")) {
   				OutParType.Theta[j][l].ParFamType = pfBinomial;  strcpy(ParFamType[i], "binomial");
 
@@ -1967,6 +2013,13 @@ void RInformationCriterionH(double *h,           /* Sides of the hypersquare. */
 				OutParType.Theta[j][l].Par1 = Par1[i];
 			}
 			else
+			if (!strcmp(ParFamType[i], "GAMMA")) {
+  				OutParType.Theta[j][l].ParFamType = pfGamma;  strcpy(ParFamType[i], "gamma");
+
+				OutParType.Theta[j][l].Par0 = Par0[i];
+				OutParType.Theta[j][l].Par1 = Par1[i];
+			}
+			else
 			if (!strcmp(ParFamType[i], "BINOMIAL")) {
   				OutParType.Theta[j][l].ParFamType = pfBinomial;  strcpy(ParFamType[i], "binomial");
 
